@@ -11,14 +11,10 @@ import pandas as pd
 import scipy.cluster.hierarchy as sch
 from scipy.spatial.distance import squareform
 from scipy.optimize import Bounds, LinearConstraint, minimize
-from sklearn.ensemble import GradientBoostingRegressor
-from sklearn.linear_model import LinearRegression
+
 # Local packages
 from napoleontoolbox.utility import metrics
 
-from sklearn.ensemble import RandomForestClassifier
-from sklearn.datasets import make_classification
-
 from napoleontoolbox.rebalancing import rolling
 
 
